#ifndef _CONFIG_H_
#define _CONFIG_H_

#include <stdio.h>
#include <string.h>
#include <syslog.h>
#include <stdbool.h>
#include <stdlib.h>

#include <libubox/list.h>

#define MAX_BUFFER_SIZE 	65536  // Fixed buffer size for downloaded content
#define MAX_URL_LENGTH 		1024
#define MAX_NAME_LENGTH 	256
#define MAX_TIME_LENGTH 	9
#define MAX_WEEK_DAYS 		7

#define FILTER_ACTIVE 		1
#define FILTER_INACTIVE 	0

extern size_t dns_server_cnt;
extern char **dns_server_ip;

extern struct list_head profiles, bundles;

// Structure to handle the fixed-size buffer for downloaded data
struct fixed_memory {
	size_t size;
	char data[MAX_BUFFER_SIZE];
};

struct host {
	struct list_head list;  // Linked list of hosts
	char host_identifier[MAX_NAME_LENGTH];  // MAC address or device identifier
};

struct url_list {
	unsigned int match_cnt;
	struct list_head list;
	char url[MAX_URL_LENGTH];
};

struct urlbundle {
	struct list_head download_url;
	struct list_head custom_url;  // List of filter URLs
	struct list_head list;  // Linked list of urlbundles
	char name[MAX_NAME_LENGTH];
};

struct schedule {
	unsigned int duration;
	bool enable;
	struct list_head days;  // List of days the schedule is active
	struct list_head list;  // Linked list for multiple schedules
	char name[MAX_NAME_LENGTH];
	char start_time[MAX_TIME_LENGTH];
	bool day[MAX_WEEK_DAYS];
};

struct urlfilter {
	bool enable;
	bool access_policy;
	struct urlbundle *bundle;
	struct list_head filter_text;  // List of filter URLs
	struct list_head schedules;  // List of filter URLs
	struct list_head list;        // Linked list of filters for each profile
	char dm_parent[MAX_NAME_LENGTH];
};

struct profile {
	struct list_head hosts;   // List of hosts (struct host)
	struct list_head filters; // List of URL filters (struct urlfilter)
	struct list_head list;    // Linked list for profiles
	char name[MAX_NAME_LENGTH];
};

// This functions reads the config from the uci file and stores in structures
int read_config(void);
#endif
